ModelField class

Constructors

ModelField(String name, String type, {String? jsonKey, String? defaultValue, List<String> enumValues = const []})

Properties

defaultValue → String?
final
enumValues → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
isEnum → bool
no setter
isMap → bool
no setter
isMapList → bool
no setter
isOptional → bool
no setter
jsonKey → String?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

getObjectType() → String
getType() → String
getTypeOfList() → String
hasDefaultValue() → bool
isArray() → bool
isListOfObjects() → bool
isListOfPrimitives() → bool
isObject() → bool
isObjectOrListOfObject() → bool
isPrimitive() → bool
isRequired() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
typeConvert() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited