Collection class

Constructors

Collection({required String name, List<Product> products = const [], required Map<String, dynamic> data, required DateTime createdAt})
const
Collection.fromMap(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime
final
data → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
products → List<Product>
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? name, List<Product>? products, Map<String, dynamic>? data, DateTime? createdAt}) → Collection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited